# delimit ;
clear all;
set mem 1G;
set more off;
set varabbrev off;

local data_dir "Data";
local out_dir "Tables";
local fig_dir "Figures";


local filename "`out_dir'\app_can_to_usa_by_can.txt";
insheet using "`data_dir'\can_to_usa_by_can.csv";

/*
local filename "`out_dir'\app_can_to_usa_by_usa.txt";
insheet using "`data_dir'\can_to_usa_by_usa.csv";
*/
/*
local filename "`out_dir'\app_usa_to_can_by_usa.txt";
insheet using "`data_dir'\usa_to_can_by_usa.csv";
*/
/*
local filename "`out_dir'\app_usa_to_can_by_can.txt";
insheet using "`data_dir'\usa_to_can_by_can.csv";
*/
keep period commoditycode tradevalue;
rename commoditycode code;
rename tradevalue value;
rename period year;

reshape wide value, i(code) j(year);

forvalues i=1981(1)2001{;
	replace value`i' = 0 if value`i'==.;
};

forvalues i=1982(1)2001{;
	local im = `i' - 1;
	gen birth`i' = 0;
	replace birth`i' = 1 if (value`i'>10) & (value`im'<10);
	
	gen death`i' = 0;
	replace death`i' = 1 if (value`i'<10) & (value`im'>10);
};

preserve;
collapse (sum) birth* death*;


file open fout using `filename', w replace;
forvalues i=1982(1)2001{;
	local b = birth`i';
	local d = death`i';
	
	file write fout "`i'" _tab "`b'" _tab "`d'" _newline;
};
file close fout;
restore;


***********************make figure**********************************************************************************;
insheet using "`data_dir'\usa_to_can_by_can.csv", clear;
keep period commoditycode tradevalue;
rename commoditycode code;
rename tradevalue value;
rename period year;
reshape wide value, i(code) j(year);
keep if code==74930;
keep value* code;
reshape long;
rename value y_by_can;
replace y_by_can = y_by_can/1000000;
save temp, replace;

insheet using "`data_dir'\usa_to_can_by_usa.csv", clear;
keep period commoditycode tradevalue;
rename commoditycode code;
rename tradevalue value;
rename period year;
reshape wide value, i(code) j(year);
keep if code==74930;
keep value* code;
reshape long;
rename value y_by_usa;
replace y_by_usa = y_by_usa/1000000;

merge 1:1 year using temp.dta;


********************************************************************************************************************;
local filename "`fig_dir'\figA1";
local line_1 "(scatter y_by_can year, c(l) lc(black) m(i) lw(medthick))";
local line_2 "(scatter y_by_usa year, c(l) lc(black) lp(dash) m(i) lw(medthick))";
local x_axis_values "1981(2)2001";
local y_axis_values "0(100)600";
local text_1 "text(100 1989 `"Measured by U.S."', place(e) size(medium))";
local text_2 "text(200 1987.5 `"Measured by Canada"', place(w) size(medium))";

graph set window fontface "Arial";

graph twoway    `line_1' `line_2',
				xsize(6)
				ysize(3.5)
				leg(off)
				ylab(`y_axis_values',nogrid tp(crossing) format(%3.0f) labsize(medsmall) angle(horizontal) labgap(vsmall))
				xlab(`x_axis_values',nogrid tp(crossing) format(%4.0f) labsize(medsmall) labgap(vsmall))
				xtitle("", margin(top)) 
				ytitle("trade value (million USD)", margin(right) size(medium) )
				`text_1' `text_2' 
				plotregion(lstyle(none) margin(sides) color(white))
				graphregion(color(white) 
);

graph export `filename'.eps, replace;
erase temp.dta;

